Enum exprz::Expr [−][src]
Canonical Concrete Expression Type
Variants
Atom(E::Atom)Atomic element
Group(E::Group)Grouped expression
Implementations
impl<E> Expr<E> where
E: Expression, [src]
E: Expression,
#[must_use]pub fn is_atom(&self) -> bool[src]
Checks if the Expr is atomic.
#[must_use]pub fn is_group(&self) -> bool[src]
Checks if the Expr is a grouped expression.
#[must_use]pub fn atom(self) -> Option<E::Atom>[src]
Converts from an Expr<E> to an Option<E::Atom>.
#[must_use]pub fn atom_ref(&self) -> Option<&E::Atom>[src]
Converts from an &Expr<E> to an Option<&E::Atom>.
#[must_use]pub fn group(self) -> Option<E::Group>[src]
Converts from an Expr<E> to an Option<E::Group>.
#[must_use]pub fn group_ref(&self) -> Option<&E::Group>[src]
Converts from an &Expr<E> to an Option<&E::Group>.
pub fn unwrap_atom(self) -> E::Atom[src]
Returns the contained Atom value, consuming the self value.
Panics
Panics if the self value is a Group.
pub fn unwrap_group(self) -> E::Group[src]
Returns the contained Group value, consuming the self value.
Panics
Panics if the self value is an Atom.
pub fn map<O, F>(self, f: F) -> O where
E::Group: IntoIterator<Item = E>,
O: Expression,
O::Group: FromIterator<O>,
F: FnMut(E::Atom) -> O::Atom, [src]
E::Group: IntoIterator<Item = E>,
O: Expression,
O::Group: FromIterator<O>,
F: FnMut(E::Atom) -> O::Atom,
Extends a function on Atoms to a function on Expressions.
pub fn substitute<F>(self, f: F) -> E where
E::Group: FromIterator<E> + IntoIterator<Item = E>,
F: FnMut(E::Atom) -> E, [src]
E::Group: FromIterator<E> + IntoIterator<Item = E>,
F: FnMut(E::Atom) -> E,
Substitutes an Expression into each Atom of self.